@@ -434,6 +434,9 @@ class CaenN6725(object):
         while delta_t <= seconds:
             if self.has_dpp_pha_firmware:
                 events = self.digitizer.read_data(fill_histogram)
+                events = []
+                for ch in range(8):
+                    events.append(self.digitizer.get_last_waveform(ch))
             else:
                 events = self.digitizer.readout_and_return()
             delta_t += time.monotonic() - last 
